@@ -17,10 +17,10 @@
 
 #include "saveimagedialog.h"
 
+#include "Logger.h"
 #include "mltcontroller.h"
 #include "settings.h"
 #include "util.h"
-#include <Logger.h>
 
 #include <QDebug>
 #include <QtMath>
@@ -28,7 +28,7 @@
 static QString suffixFromFilter(const QString &filterText)
 {
     QString suffix = filterText.section("*", 1, 1).section(")", 0, 0).section(" ", 0, 0);
-    if (!suffix.startsWith(".") ) {
+    if (!suffix.startsWith(".")) {
         suffix.clear();
     }
     return suffix;
@@ -44,8 +44,8 @@ SaveImageDialog::SaveImageDialog(QWidget *parent, const QString &caption, QImage
     setOptions(Util::getFileDialogOptions());
     setDirectory(Settings.savePath());
 
-    QString nameFilter =
-        tr("PNG (*.png);;BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PPM (*.ppm);;TIFF (*.tif *.tiff);;WebP (*.webp);;All Files (*)");
+    QString nameFilter = tr("PNG (*.png);;BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PPM (*.ppm);;TIFF "
+                            "(*.tif *.tiff);;WebP (*.webp);;All Files (*)");
     setNameFilter(nameFilter);
 
     QStringList nameFilters = nameFilter.split(";;");
@@ -60,8 +60,8 @@ SaveImageDialog::SaveImageDialog(QWidget *parent, const QString &caption, QImage
     selectNameFilter(selectedNameFilter);
 
     // Use the current player time as a suggested file name
-    QString nameSuggestion = QStringLiteral("Shotcut_%1").arg(MLT.producer()->frame_time(
-                                                                  mlt_time_clock));
+    QString nameSuggestion
+        = QStringLiteral("Shotcut_%1").arg(MLT.producer()->frame_time(mlt_time_clock));
     nameSuggestion = nameSuggestion.replace(":", "_");
     nameSuggestion = nameSuggestion.replace(".", "_");
     nameSuggestion += suffix;
@@ -69,7 +69,8 @@ SaveImageDialog::SaveImageDialog(QWidget *parent, const QString &caption, QImage
 
 #if !defined(Q_OS_WIN)
     if (!connect(this, &QFileDialog::filterSelected, this, &SaveImageDialog::onFilterSelected))
-        connect(this, SIGNAL(filterSelected(const QString &)),
+        connect(this,
+                SIGNAL(filterSelected(const QString &)),
                 SLOT(const onFilterSelected(const QString &)));
 #endif
     if (!connect(this, &QFileDialog::fileSelected, this, &SaveImageDialog::onFileSelected))
@@ -110,7 +111,7 @@ void SaveImageDialog::onFileSelected(const QString &file)
     QFileInfo fi(m_saveFile);
     if (fi.suffix().isEmpty()) {
         QString suffix = suffixFromFilter(selectedNameFilter());
-        if ( suffix.isEmpty() ) {
+        if (suffix.isEmpty()) {
             suffix = ".png";
         }
         m_saveFile += suffix;
@@ -121,8 +122,10 @@ void SaveImageDialog::onFileSelected(const QString &file)
     // Convert to square pixels if needed.
     qreal aspectRatio = (qreal) m_image.width() / m_image.height();
     if (qFloor(aspectRatio * 1000) != qFloor(MLT.profile().dar() * 1000)) {
-        m_image = m_image.scaled(qRound(m_image.height() * MLT.profile().dar()), m_image.height(),
-                                 Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        m_image = m_image.scaled(qRound(m_image.height() * MLT.profile().dar()),
+                                 m_image.height(),
+                                 Qt::IgnoreAspectRatio,
+                                 Qt::SmoothTransformation);
     }
     m_image.save(m_saveFile, Q_NULLPTR, (fi.suffix() == "webp") ? 80 : -1);
     Settings.setSavePath(fi.path());
