@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2023 Meltytech, LLC
+ * Copyright (c) 2013-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,32 +18,33 @@
 #ifndef FILTERSDOCK_H
 #define FILTERSDOCK_H
 
+#include "qmltypes/qmlproducer.h"
+#include "sharedframe.h"
+
 #include <QDockWidget>
 #include <QObject>
 #include <QQuickView>
 #include <QQuickWidget>
 
-#include "sharedframe.h"
-#include "qmltypes/qmlproducer.h"
-
 class QmlFilter;
 class QmlMetadata;
 class MetadataModel;
 class AttachedFiltersModel;
 class MotionTrackerModel;
+class SubtitlesModel;
 
 class FiltersDock : public QDockWidget
 {
     Q_OBJECT
 
 public:
-    explicit FiltersDock(MetadataModel *metadataModel, AttachedFiltersModel *attachedModel,
-                         MotionTrackerModel *motionTrackerModel, QWidget *parent = 0);
+    explicit FiltersDock(MetadataModel *metadataModel,
+                         AttachedFiltersModel *attachedModel,
+                         MotionTrackerModel *motionTrackerModel,
+                         SubtitlesModel *subtitlesModel,
+                         QWidget *parent = 0);
 
-    QmlProducer *qmlProducer()
-    {
-        return &m_producer;
-    }
+    QmlProducer *qmlProducer() { return &m_producer; }
 
 signals:
     void currentFilterRequested(int attachedIndex);
@@ -57,8 +58,9 @@ public slots:
     void onSeeked(int position);
     void onShowFrame(const SharedFrame &frame);
     void openFilterMenu() const;
+    void showCopyFilterMenu();
     void onServiceInChanged(int delta, Mlt::Service *service);
-    void resetQview();
+    void load();
 
 protected:
     bool event(QEvent *event);
@@ -68,6 +70,7 @@ private:
     void setupActions();
     QQuickWidget m_qview;
     QmlProducer m_producer;
+    unsigned loadTries{0};
 };
 
 #endif // FILTERSDOCK_H
