@@ -16,15 +16,16 @@
  */
 
 #include "gopro2gpxjob.h"
-#include "mainwindow.h"
+
+#include "Logger.h"
 #include "dialogs/textviewerdialog.h"
+#include "mainwindow.h"
 #include "util.h"
 
 #include <QAction>
 #include <QApplication>
-#include <QFileInfo>
 #include <QDir>
-#include <Logger.h>
+#include <QFileInfo>
 
 GoPro2GpxJob::GoPro2GpxJob(const QString &name, const QStringList &args)
     : AbstractJob(name)
@@ -38,6 +39,6 @@ void GoPro2GpxJob::start()
     QString shotcutPath = qApp->applicationDirPath();
     QFileInfo gopro2gpxPath(shotcutPath, "gopro2gpx");
     setReadChannel(QProcess::StandardOutput);
-    LOG_DEBUG() << gopro2gpxPath.absoluteFilePath()  + " " + m_args.join(' ');
+    LOG_DEBUG() << gopro2gpxPath.absoluteFilePath() + " " + m_args.join(' ');
     AbstractJob::start(gopro2gpxPath.absoluteFilePath(), m_args);
 }
